@@ -82,6 +82,11 @@ class RunCommand:
         else:
             self.close_fds = False
 
+        if 'stderr_as_stdout' in kwargs:
+            self.stderr_as_stdout = kwargs['stderr_as_stdout']
+        else:
+            self.stderr_as_stdout = False
+
         if 'platform_option' in kwargs:
             self.platform_option = kwargs['platform_option']
             if not isinstance(self.platform_option, PlatformOptionsWindows) and not isinstance(self.platform_option, PlatformOptionsPosix):
@@ -98,53 +103,92 @@ class RunCommand:
             if self.trace_on:
                 self.__print_trace(self.__show_trace_prefix() + command_line)
 
-
             if self.platform_option is not None:
                 args = self.platform_option.forwarder.args
             else:
                 args = {}
 
-            with subprocess.Popen(
-                self.__cmd(command_line),
-                stdin=RunCommand.__stdin(in_arg),
-                close_fds=self.close_fds,
-                shell=self.use_shell,
-                stdout=subprocess.PIPE,
-                stderr=subprocess.PIPE,
-                env = self.env,
-                **args
-            ) as process:
+            if not self.stderr_as_stdout:
+                with subprocess.Popen(
+                    self.__cmd(command_line),
+                    stdin=RunCommand.__stdin(in_arg),
+                    close_fds=self.close_fds,
+                    shell=self.use_shell,
+                    stdout=subprocess.PIPE,
+                    stderr=subprocess.PIPE,
+                    env = self.env,
+                    **args
+                ) as process:
 
-                self.command_line = command_line
+                    self.command_line = command_line
 
-                (output, error_out) = process.communicate(
-                        input=RunCommand.__input(in_arg),
-                        timeout=self.timeout_seconds)
+                    (output, error_out) = process.communicate(
+                            input=RunCommand.__input(in_arg),
+                            timeout=self.timeout_seconds)
 
-                self.exit_code = process.wait()
-                if self.convert_to_text is not None:
-                    self.output = output.decode(self.convert_to_text)
-                else:
-                    self.output = output
+                    self.exit_code = process.wait()
+                    if self.convert_to_text is not None:
+                        self.output = output.decode(self.convert_to_text)
+                    else:
+                        self.output = output
 
-                if self.convert_to_text is not None:
-                    self.error_out = error_out.decode(self.convert_to_text)
-                else:
-                    self.error_out = error_out
+                    if self.convert_to_text is not None:
+                        self.error_out = error_out.decode(self.convert_to_text)
+                    else:
+                        self.error_out = error_out
 
-                self.exit_code = process.wait()
+                    self.exit_code = process.wait()
 
-                if self.trace_on:
-                    msg = self.__show_trace_prefix() + "exit_code: " + str(self.exit_code)
-                    if self.output != "":
-                        msg += "\n stdout:\n" + RunCommand.__output_rep(self.output)
-                    if self.error_out != "":
-                        msg += "\n  stderr:\n" + RunCommand.__output_rep(self.error_out)
-                    self.__print_trace(msg)
+                    if self.trace_on:
+                        msg = self.__show_trace_prefix() + "exit_code: " + str(self.exit_code)
+                        if self.output != "":
+                            msg += "\n stdout:\n" + RunCommand.__output_rep(self.output)
+                        if self.error_out != "":
+                            msg += "\n  stderr:\n" + RunCommand.__output_rep(self.error_out)
+                        self.__print_trace(msg)
 
-                if self.exit_on_error and self.exit_code != 0:
-                    self.__print_trace(self.__make_error_message())
-                    sys.exit(1)
+                    # common to both cases of stderr_as_stdout
+                    if self.exit_on_error and self.exit_code != 0:
+                        self.__print_trace(self.__make_error_message())
+                        sys.exit(1)
+
+            #if self.stderr_as_stdout:
+            else:
+                with subprocess.Popen(
+                    self.__cmd(command_line),
+                    stdin=RunCommand.__stdin(in_arg),
+                    close_fds=self.close_fds,
+                    shell=self.use_shell,
+                    stdout=subprocess.PIPE,
+                    stderr=subprocess.STDOUT,
+                    env = self.env,
+                    **args
+                ) as process:
+
+                    self.command_line = command_line
+
+                    (output, _) = process.communicate(
+                            input=RunCommand.__input(in_arg),
+                            timeout=self.timeout_seconds)
+
+                    self.exit_code = process.wait()
+                    if self.convert_to_text is not None:
+                        self.output = output.decode(self.convert_to_text)
+                    else:
+                        self.output = output
+
+                    self.exit_code = process.wait()
+
+                    if self.trace_on:
+                        msg = self.__show_trace_prefix() + "exit_code: " + str(self.exit_code)
+                        if self.output != "":
+                            msg += "\n stdout:\n" + RunCommand.__output_rep(self.output)
+                        self.__print_trace(msg)
+
+                    # common to both cases of stderr_as_stdout
+                    if self.exit_on_error and self.exit_code != 0:
+                        self.__print_trace(self.__make_error_message())
+                        sys.exit(1)
 
                 return self.exit_code
 
